==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorTokenHOTPProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHOTPProfile
 */
@JsonPropertyOrder({ UserFactorTokenHOTPProfile.JSON_PROPERTY_SHARED_SECRET })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenHOTPProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SHARED_SECRET = "sharedSecret";
    private String sharedSecret;

    public UserFactorTokenHOTPProfile() {
    }

    public UserFactorTokenHOTPProfile sharedSecret(String sharedSecret) {

        this.sharedSecret = sharedSecret;
        return this;
    }

    /**
     * Unique secret key used to generate the OTP
     *
     * @return sharedSecret
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "484f97be3213b117e3a20438e291540a", value = "Unique secret key used to generate the OTP")
    @JsonProperty(JSON_PROPERTY_SHARED_SECRET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSharedSecret() {
        return sharedSecret;
    }

    @JsonProperty(JSON_PROPERTY_SHARED_SECRET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSharedSecret(String sharedSecret) {
        this.sharedSecret = sharedSecret;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHOTPProfile userFactorTokenHOTPProfile = (UserFactorTokenHOTPProfile) o;
        return Objects.equals(this.sharedSecret, userFactorTokenHOTPProfile.sharedSecret);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sharedSecret);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHOTPProfile {\n");
        sb.append("    sharedSecret: ").append(toIndentedString(sharedSecret)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorTokenHOTPProfile.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorTokenHOTPProfile
 */
@JsonPropertyOrder({ UserFactorTokenHOTPProfile.JSON_PROPERTY_SHARED_SECRET })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorTokenHOTPProfile implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SHARED_SECRET = "sharedSecret";
    private String sharedSecret;

    public UserFactorTokenHOTPProfile() {
    }

    public UserFactorTokenHOTPProfile sharedSecret(String sharedSecret) {

        this.sharedSecret = sharedSecret;
        return this;
    }

    /**
     * Unique secret key used to generate the OTP
     *
     * @return sharedSecret
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(example = "484f97be3213b117e3a20438e291540a", value = "Unique secret key used to generate the OTP")
    @JsonProperty(JSON_PROPERTY_SHARED_SECRET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getSharedSecret() {
        return sharedSecret;
    }

    @JsonProperty(JSON_PROPERTY_SHARED_SECRET)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSharedSecret(String sharedSecret) {
        this.sharedSecret = sharedSecret;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorTokenHOTPProfile userFactorTokenHOTPProfile = (UserFactorTokenHOTPProfile) o;
        return Objects.equals(this.sharedSecret, userFactorTokenHOTPProfile.sharedSecret);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(sharedSecret);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorTokenHOTPProfile {\n");
        sb.append("    sharedSecret: ").append(toIndentedString(sharedSecret)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
